@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::ReadmeFromPod;
 our $AUTHORITY = 'cpan:FAYLAND';
-$Dist::Zilla::Plugin::ReadmeFromPod::VERSION = '0.34';
+$Dist::Zilla::Plugin::ReadmeFromPod::VERSION = '0.35';
 use Moose;
 use List::Util 1.33 qw( first );
 with 'Dist::Zilla::Role::InstallTool' => { -version => 5 }; # after PodWeaver
@@ -87,7 +87,7 @@ sub setup_installer {
             'pod'      => 'pod'
         );
         foreach my $e (keys %ext) {
-            my $test_readme_file = $self->zilla->root->file($e ? "README.$e" : 'README');
+            my $test_readme_file = $self->zilla->root->child($e ? "README.$e" : 'README');
             if (-e "$test_readme_file") {
                 $readme_file = $test_readme_file;
                 $pod_class = $FORMATS{ $ext{$e} }->{class};
@@ -107,7 +107,7 @@ sub setup_installer {
     $prf->run();
 
     if ($readme_file) {
-        return $readme_file->spew(iomode => '>:raw', $content);
+        return $readme_file->spew_raw($content);
     }
 
     $readme_name ||= $prf->default_readme_file;
